# tkinterDnD
A nice wrapper around the tkdnd package. No tcl installation, no build is required, just download and use it! (Nevertheless, I recommend having tcl installed 😉️)


### Credits:

```
Copyright (c) 2021 rdbende
Copyright (c) 2012-2020 Petasis - the tkdnd package
Copyright (c) 2020 Philippe Gagné - for Mac binaries: https://github.com/pmgagne/tkinterdnd2/tree/master/tkinterdnd2/tkdnd/osx64
Copyright (c) 2017 Michael Lange - the TkinterDnD package
```
### Install
The Pypi name is python-tkdnd, because tkinterDnD was already taken, but you can import it with `import tkinterDnD`

```
pip install python-tkdnd
```
or
```
pip3 install python-tkdnd
```

<br>

There's also an example program on how to use drag from and drop to events\
![image](https://user-images.githubusercontent.com/77941087/123248502-4b8d8880-d4e8-11eb-947d-ec883a0b1795.png)
